@@ -298,10 +298,10 @@ class OatClient:
             fn="set_gelineq",
             args={
                 "coefficients": _wrap_arg([
-                    {
+                    _wrap_arg({
                         "id": _wrap_arg(self._resolve_id(k)),
                         "coefficient": _wrap_arg(v)
-                    }
+                    })
                     for k, v in coefficients.items()
                 ]),
                 "bias": _wrap_arg(bias),
